function YADADeleteTmpFiles(DSGEModel)
% YADADeleteTmpFiles: Tries to delete files copied to the tmp directory for a given model in YADA.
%
% USAGE:
%
%       YADADeleteTmpFiles(DSGEModel)
%
% REQUIRED INPUT: DSGEModel (structure) whose fields contain all required information 
%                           about the model, such as input files, variable and sample
%                           data. Actual observations are not stored in this file.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: February 18, 2015.
%                        This version: February 9, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 19-02-2015: Added code for deleting the files "compute_aim_matrices.m" and "compute_aim_data.m"
%               from the "tmp" directory.
%
% * 20-01-2016: Updated the documentation.
%
% * 09-02-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if isfield(DSGEModel,'DataConstructionFile')==1;
   DCF = FixFilePath([pwd '\tmp\' GetFilename(DSGEModel.DataConstructionFile)]);
   if FileExist(DCF)==1;
      delete(DCF);
   end;
end;
if isfield(DSGEModel,'MeasurementEquationFile')==1;
   MEF = FixFilePath([pwd '\tmp\' GetFilename(DSGEModel.MeasurementEquationFile)]);
   if FileExist(MEF)==1;
      delete(MEF);
   end;
end;
if isfield(DSGEModel,'UpdateParameterFile')==1;
   UPF = FixFilePath([pwd '\tmp\' GetFilename(DSGEModel.UpdateParameterFile)]);
   if FileExist(UPF)==1;
      delete(UPF);
   end;
end;
if isfield(DSGEModel,'InitializeParameterFile')==1;
   IPF = FixFilePath([pwd '\tmp\' GetFilename(DSGEModel.InitializeParameterFile)]);
   if FileExist(IPF)==1;
      delete(IPF);
   end;
end;
if isfield(DSGEModel,'SteadyStatePriorFile')==1;
   SSPF = FixFilePath([pwd '\tmp\' GetFilename(DSGEModel.SteadyStatePriorFile)]);
   if FileExist(SSPF)==1;
      delete(SSPF);
   end;
end;
if FileExist(FixFilePath([pwd '\tmp\compute_aim_matrices.m']))==1;
   delete(FixFilePath([pwd '\tmp\compute_aim_matrices.m']));
end;
if FileExist(FixFilePath([pwd '\tmp\compute_aim_data.m']))==1;
   delete(FixFilePath([pwd '\tmp\compute_aim_data.m']));
end;

%
% end of YADADeleteTmpFiles.m
%
