function [VersionOfYADA,VersionDateStr] = YADAVersion
% YADAVersion: provides the current version number of YADA
%
% USAGE:
%
%       [VersionOfYADA,VersionDateStr] = YADAVersion
%
% REQUIRED OUTPUT: VersionOfYADA (integer) with the current version number of YADA.
%
% OPTIONAL OUTPUT: VersionDateStr (string vector) with the date when the YADAGUI was last
%                                 edited.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: July 25, 2006.
%                        This version: February 9, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 14-01-2008: Added the output argument "VersionDateStr".
%
% * 23-05-2008: Updated the documentation.
%
% * 27-06-2008: Changed the version number from 1.00 to 1.10.
%
% * 25-08-2008: Changed the version number from 1.10 to 1.20.
%
% * 16-09-2008: Changed the version number from 1.20 to 1.30.
%
% * 22-09-2008: Changed the version number from 1.30 to 1.40.
%
% * 01-12-2008: Changed the version number from 1.40 to 1.50.
%
% * 05-12-2008: Updated the documentation.
%
% * 05-01-2009: Changed the version number from 1.50 to 1.60.
%
% * 12-03-2009: New version number is 1.80. Why? The previous version
%               had so many new features.
%
% * 21-04-2009: A swift move to version 1.90. Yeah, we made it there.
%
% * 17-08-2009: Now we move to version 2.00.
%
% * 15-10-2009: We've moved on to a new dimension... 2.10.
%
% * 05-01-2010: Updated the documentation.
%
% * 11-01-2010: The version number is now 2.20.
%
% * 28-04-2010: And now it's 2.30!
%
% * 10-06-2010: Next jump is taken. This time we reach 2.40.
%
% * 30-09-2010: It's time to move on. Now for version 2.50.
%
% * 29-11-2010: Next step, version 2.60.
%
% * 04-01-2011: Updated the documentation.
%
% * 07-01-2011: Now we go for 2.70.
%
% * 12-01-2011: The function now supports unix and mac paths.
%
% * 16-02-2011: We now move on the version 2.80.
%
% * 04-04-2011: Version is now 2.90.
%
% * 29-06-2011: And this time we go for 3.00.
%
% * 29-09-2011: At the sounds of the Tangent the version has switched to 3.10.
%
% * 02-01-2011: Updated the documentation.
%
% * 19-03-2012: We now turn to version 3.20.
%
% * 05-11-2012: The next version is, suprisingly, 3.30.
%
% * 02-01-2013: Updated the documentation.
%
% * 17-01-2013: Changed the version number to 3.40.
%
% * 12-08-2013: And now to 3.50!
%
% * 04-11-2013: We now move to 3.60.
%
% * 24-01-2014: Updated the documentation.
%
% * 04-04-2014: We're now pushing for 3.70.
%
% * 05-01-2015: With a new year we move to version 3.80.
%
% * 30-04-2015: Now we switch to version 3.90, the last in the 3.xx series.
%
% * 29-09-2015: Now we go for version 4.00.
%
% * 20-01-2016: Updated the documentation.
%
% * 08-11-2016: Version 4.10 is now being developed.
%
% * 09-02-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

VersionOfYADA = 4.10;
if nargout==2;
   VersionDateStr = GetFileDate(FixFilePath([pwd '\YADAGUI.m']));
end;

%
% end of YADAVersion.m
%
