function ShockColors = CreateShockColors(ShockGroups,ShockGroupColors)
% CreateShockColors: Creates colors for the different shocks based on the colors for the shock groups.
%
% USAGE:
%
%       ShockColors = CreateShockColors(ShockGroups,ShockGroupColors)
%
% REQUIRED INPUT:  ShockGroups (vector) of dimension q with integer values between 1 and q1<q.
%
%                  ShockGroupColors (matrix) of dimension q1x3 with the colors for the different
%                                   shock groups.
%
% REQUIRED OUTPUT: ShockColors (matrix) of dimension qx3 with the colors for the shocks based on
%                                   the ShockGroup they belong to.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: April 18, 2011.
%                        This version: February 10, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 19-04-2011: Updated the documentation.
%
% * 03-01-2012: Updated the documentation.
%
% * 02-01-2013: Updated the documentation.
%
% * 24-01-2014: Updated the documentation.
%
% * 05-01-2015: Updated the documentation.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

q = length(ShockGroups);
q1 = max(ShockGroups);
ShockColors = zeros(q,3);
ShockGroupColors = ShockGroupColors(unique(ShockGroups),:);
%
% loop over the shock groups
%
for i=1:q1;
   Positions = (i==ShockGroups).*(1:q);
   Positions = Positions(Positions>0);
   NumShocks = length(Positions);
   ShockColor = ones(NumShocks,1)*ShockGroupColors(i,:);
   if NumShocks>1;
      for j=1:NumShocks;
         ShockColor(j,:) = ((1+(2*(j-1)))/(2*NumShocks))*ShockGroupColors(i,:);
      end;
   end;
   ShockColors(Positions,:) = ShockColor;
end;

%
% end of CreateShockColors.m
%
