function status = DSGEMomentsResponseExist(ParameterNames,ParamNumber,OutputType,CurrChain,IsPosterior,NumDraws,TotalDraws,DSGEModel,CurrINI)
% DSGEMomentsResponseExist: Tests if the effects from a parameter change on the means, standard deviation and
%                           correlations have already been calculated for selected parameter.
%
% USAGE:
%
%       status = DSGEMomentsResponseExist(ParameterNames,ParamNumber,OutputType,CurrChain,IsPosterior,NumDraws,...
%                                         TotalDraws,DSGEModel,CurrINI)
%
% REQUIRED INPUT:  ParameterNames (string matrix) with the names of the parameters.
%
%                  ParamNumber (integer) with the position of the parameter in theta to change.
%
%                  OutputType (boolean) that takes the value 1 if responses to the moments should be computed
%                             for the observed variables, and 0 if the responses should be computed for the
%                             state variables.
%
%                  CurrChain (integer) with the number for the current Markov chain.
%
%                  IsPosterior (boolean) that is 1 if draws from the posterior distribution are used and 0
%                             if draws from the prior are supplied.
%
%                  NumDraws (integer) with total number of parameter draws actually used.
%
%                  TotalDraws (integer) with the total number of draws that could have been used.
%
%                  DSGEModel (structure) with fields containing all the information about a DSGE Model for YADA.
%
%                  CurrINI (structure) with initialization information.
%
% REQUIRED OUTPUT: status (boolean) that indicates if the coherence statistics have already been calculated or not.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: March 25, 2014.
%                        This version: March 21, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 26-03-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 22-01-2016: Updated the documentation.
%
% * 21-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% intialize
%
status = 0;
ParamStr = StringTrim(ParameterNames(ParamNumber,:));
SaveAfterDraws = min(NumDraws,100);
NumFiles = ceil(NumDraws/SaveAfterDraws);
for ThisSave=1:NumFiles;
   if OutputType==1;
      if IsPosterior==1;
         file = FixFilePath([DSGEModel.OutputDirectory '\paramchange\DSGE-ObsVar-ParamChange-' ParamStr '-' DSGEModel.NameOfModel '-' int2str(CurrChain) '-' int2str(ThisSave) '-' int2str(NumFiles) '.' int2str(NumDraws) '-' int2str(TotalDraws) '.mat']);
      else;
         file = FixFilePath([DSGEModel.OutputDirectory '\paramchange\DSGE-ObsVar-ParamChange-Prior-' ParamStr '-' DSGEModel.NameOfModel '-' int2str(ThisSave) '-' int2str(NumFiles) '.' int2str(NumDraws) '.mat']);
      end;
   else;
      if IsPosterior==1;
         file = FixFilePath([DSGEModel.OutputDirectory '\paramchange\DSGE-StateVar-ParamChange-' ParamStr '-' DSGEModel.NameOfModel '-' int2str(CurrChain) '-' int2str(ThisSave) '-' int2str(NumFiles) '.' int2str(NumDraws) '-' int2str(TotalDraws) '.mat']);
      else;
         file = FixFilePath([DSGEModel.OutputDirectory '\paramchange\DSGE-StateVar-ParamChange-Prior-' ParamStr '-' DSGEModel.NameOfModel '-' int2str(ThisSave) '-' int2str(NumFiles) '.' int2str(NumDraws) '.mat']);
      end;
   end;
   if FileExist(file)==0;
      return;
   end;
end;
status = 1;

%
% end of DSGEMomentsResponseExist.m
%
