function stat = IsWinXP
% IsWinXP: Tests if Matlab is run on a Windows XP computer.
%
% USAGE:
%
%       stat = IsWinXP
%
% REQUIRED OUTPUT: stat (integer). Returns 1 if you are running Windows XP, 2 for Windows Vista,
%                       3 for Windows 7, -1 for Unix and Mac, and 0 otherwise.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2013 European Central Bank.
%
%                       First version: July 21, 2006.
%                        This version: January 3, 2013.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-11-2007: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 08-12-2008: Added the quotes around the call to exe-files.
%
% * 09-12-2008: Removed quotes around the directory parameter for the iswinxp.exe call.
%
% * 03-05-2009: Updated the documentation.
%
% * 30-06-2009: IsWinXP.m now also tests if it is running on a 64-bit windows operating system.
%
% * 05-01-2010: Updated the documentation.
%
% * 28-01-2010: The function now outputs stat=2 if the user has Windows Vista, and stat=3
%               if the user has Windows 7.
%
% * 05-01-2011: Updated the documentation.
%
% * 09-01-2011: The function now supports unix and mac.
%
% * 27-01-2011: The function now reports -1 for unix and mac.
%
% * 04-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if isunix==1;
   stat = -1;
   return;
end;
file = [pwd '\iswinxp.txt'];
if FileExist(file)==1;
   txt = ReadText(file);
   if min(size(txt))==1;
      txt = txt{1};
      txt = strrep(txt,' ','');
      stat = str2double(txt);
      if isnumeric(stat)==1;
         return;
      end;
   end;
end;
%
stat = 0;
if (strcmp(computer,'PCWIN')==1)|(strcmp(computer,'PCWIN64')==1);
   prog = ['"' pwd '\bin\iswinxp.exe" ' pwd];
   stat_e = dos(prog);
   if FileExist(file)==1;
      txt = ReadText(file);
      if min(size(txt))==1;
         txt = txt{1};
         txt = strrep(txt,' ','');
         stat = str2double(txt);
         if isnumeric(stat)==0;
            stat = 0;
         end;
      end;
   else;
      fid = fopen(file,'wt');
      fprintf(fid,'0\n');
      fclose(fid);
   end;
end;

%
% end of IsWinXP.m
%
