function ldSigma = LogDet(Sigma)
% Logdet: Computes the log-determinant of a matrix Sigma using a robust method.
%
% USAGE:
%
%       ldSigma = LogDet(Sigma)
%
% REQUIRED INPUT:  Sigma (nxn) matrix for which the log-determinant should be computed
%
% REQUIRED OUTPUT: ldSigma (scalar) with the value of the log-determinant
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: July 20, 2012.
%                        This version: March 21, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 26-07-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 27-01-2016: Remember Shoah.
%
% * 21-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

try;
   ldSigma = log(det(Sigma));
   if isinf(ldSigma)==0;
      return;
   end;
   ldSigma = 2*sum(log(diag(chol(Sigma))));
catch;
   [L,U,P] = lu(Sigma);
   du = diag(U);
   c = det(P)*prod(sign(du));
   ldSigma = log(c)+sum(log(abs(du))); 
end;

%
% end of LogDet.m
%
