function controls = BVARMenuControls(maingui,controls)
% BVARMenuControls: sets up the BVAR menu.
%
% USAGE:
%
%       controls = BVARMenuControls(maingui,controls)
%
% REQUIRED INPUT:  maingui (handle) to YADA's main dialog.
%
%                  controls (structure) with handles to the controls on the YADA main dialog.
%
% REQUIRED OUTPUT: controls (structure) with handles to the controls on the YADA main dialog.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: March 3, 2010.
%                        This version: March 21, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 04-03-2010: Updated the documentation.
%
% * 07-03-2010: Fixed some errors in callback indicators.
%
% * 05-01-2011: Updated the documentation.
%
% * 04-03-2011: Added controls for conditional predictive distributions.
%
% * 08-03-2011: Added controls for modesty statistics.
%
% * 02-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 27-01-2016: Remember Shoah.
%
% * 21-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% BVAR menu
%
controls.bvarmenu = uimenu('Parent',maingui, ...
   'Label','&BVAR', ...
   'Tag','BVARMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                         Estimate the posterior mode                         %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarmodemenu = uimenu('Parent',controls.bvarmenu, ...
   'Label','&Estimate Posterior Mode...', ...
   'Callback','BVARMenuFunctions BVARPostMode', ...
   'Enable','off', ...
   'Tag','BVARPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                            Run the Gibbs sampler                            %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.gibbssamplingmenu = uimenu('Parent',controls.bvarmenu, ...
   'Label','&Posterior Sampling...', ...
   'Callback','BVARMenuFunctions Gibbs', ...
   'Enable','off', ...
   'Tag','BVARPosteriorSamplingMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                     Display BVAR posterior mode results                     %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarmoderesultsmenu = uimenu('Parent',controls.bvarmenu, ...
   'Label','Posterior &Mode Results...', ...
   'Callback','BVARMenuFunctions BVARPostModeResults', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','BVARPosteriorModeResultsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                   Display BVAR posterior sampling results                   %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvargibbsresultsmenu = uimenu('Parent',controls.bvarmenu, ...
   'Label','Posterior &Sampling Results...', ...
   'Callback','BVARMenuFunctions BVARGibbsResults', ...
   'Enable','off', ...
   'Tag','BVARPosteriorModeResultsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                  Eigenvalues of the VAR at posterior mode                   %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvareigenvalues = uimenu('Parent',controls.bvarmenu, ...
   'Label','Ei&genvalues...', ...
   'Callback','BVARMenuFunctions BVAREigenvalues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','BVARPosteriorModeEigenvaluesMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                   Predictive distributions from the BVAR                    %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarpredict.parent = uimenu('Parent',controls.bvarmenu, ...
   'Label','Predi&ctive Distributions', ...
   'Separator','on', ...
   'Tag','BVARPredictionMenu');
%
% Unconditional predictions
%
controls.bvarpredict.unconditional.parent = uimenu('Parent',controls.bvarpredict.parent, ...
   'Label','&Unconditional', ...
   'Separator','off', ...
   'Tag','BVARUnconditionalPredictionMenu');
%
% original data
%
controls.bvarpredict.unconditional.originalparent = uimenu('Parent',controls.bvarpredict.unconditional.parent, ...
   'Label','&Original Data', ...
   'Tag','BVARUnconditionalPredictionOriginalDataMenu');
%
% annualized data
%
controls.bvarpredict.unconditional.annualparent = uimenu('Parent',controls.bvarpredict.unconditional.parent, ...
   'Label','&Annualized Data', ...
   'Tag','BVARUnconditionalPredictionAnnualizedDataMenu');
%
% posterior mode
%
controls.bvarpredict.unconditional.original.postmode = uimenu('Parent',controls.bvarpredict.unconditional.originalparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','BVARMenuFunctions BVARPredictPostMode', ...
   'Enable','off', ...
   'Tag','BVARUnconditionalPredictionOriginalDataPostModeMenu');
%
controls.bvarpredict.unconditional.annual.postmode = uimenu('Parent',controls.bvarpredict.unconditional.annualparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','BVARMenuFunctions BVARPredictPostMode', ...
   'Enable','off', ...
   'Tag','BVARUnconditionalPredictionAnnualDataPostModeMenu');
%
% posterior distribution
%
controls.bvarpredict.unconditional.original.posterior = uimenu('Parent',controls.bvarpredict.unconditional.originalparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','BVARMenuFunctions BVARPredictPosterior', ...
   'Enable','off', ...
   'Tag','BVARUnconditionalPredictionOriginalDataPostDistMenu');
%
controls.bvarpredict.unconditional.annual.posterior = uimenu('Parent',controls.bvarpredict.unconditional.annualparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','BVARMenuFunctions BVARPredictPosterior', ...
   'Enable','off', ...
   'Tag','BVARUnconditionalPredictionAnnualDataPostDistMenu');
%
% prediction event
%
controls.bvarpredict.unconditional.original.predevent = uimenu('Parent',controls.bvarpredict.unconditional.originalparent, ...
   'Label','Prediction &Event...', ...
   'Callback','BVARMenuFunctions BVARPredictionEvent', ...
   'Enable','off', ...
   'Separator','on', ...
   'Tag','BVARUnconditionalPredictionEventOriginalDataPostDistMenu');
%
controls.bvarpredict.unconditional.annual.predevent = uimenu('Parent',controls.bvarpredict.unconditional.annualparent, ...
   'Label','Prediction &Event...', ...
   'Callback','BVARMenuFunctions BVARPredictionEvent', ...
   'Enable','off', ...
   'Separator','on', ...
   'Tag','BVARUnconditionalPredictionEventAnnualDataPostDistMenu');
%
% Conditional predictions
%
controls.bvarpredict.conditional.parent = uimenu('Parent',controls.bvarpredict.parent, ...
   'Label','&Conditional', ...
   'Separator','off', ...
   'Tag','BVARConditionalPredictionMenu');
%
% original data
%
controls.bvarpredict.conditional.originalparent = uimenu('Parent',controls.bvarpredict.conditional.parent, ...
   'Label','&Original Data', ...
   'Tag','BVARConditionalPredictionOriginalDataMenu');
%
% annualized data
%
controls.bvarpredict.conditional.annualparent = uimenu('Parent',controls.bvarpredict.conditional.parent, ...
   'Label','&Annualized Data', ...
   'Tag','BVARConditionalPredictionAnnualizedDataMenu');
%
% posterior mode
%
controls.bvarpredict.conditional.original.postmode = uimenu('Parent',controls.bvarpredict.conditional.originalparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','BVARMenuFunctions BVARCondPostMode', ...
   'Enable','off', ...
   'Tag','BVARConditionalPredictionOriginalDataPostModeMenu');
%
controls.bvarpredict.conditional.annual.postmode = uimenu('Parent',controls.bvarpredict.conditional.annualparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','BVARMenuFunctions BVARCondPostMode', ...
   'Enable','off', ...
   'Tag','BVARConditionalPredictionAnnualDataPostModeMenu');
%
% posterior distribution
%
controls.bvarpredict.conditional.original.posterior = uimenu('Parent',controls.bvarpredict.conditional.originalparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','BVARMenuFunctions BVARCondPosterior', ...
   'Enable','off', ...
   'Tag','BVARConditionalPredictionOriginalDataPostDistMenu');
%
controls.bvarpredict.conditional.annual.posterior = uimenu('Parent',controls.bvarpredict.conditional.annualparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','BVARMenuFunctions BVARCondPosterior', ...
   'Enable','off', ...
   'Tag','BVARConditionalPredictionAnnualDataPostDistMenu');
%
% prediction event
%
controls.bvarpredict.conditional.original.predevent = uimenu('Parent',controls.bvarpredict.conditional.originalparent, ...
   'Label','Prediction &Event...', ...
   'Callback','BVARMenuFunctions BVARCondPredictionEvent', ...
   'Enable','off', ...
   'Separator','on', ...
   'Tag','BVARConditionalPredictionEventOriginalDataPostDistMenu');
%
controls.bvarpredict.conditional.annual.predevent = uimenu('Parent',controls.bvarpredict.conditional.annualparent, ...
   'Label','Prediction &Event...', ...
   'Callback','BVARMenuFunctions BVARCondPredictionEvent', ...
   'Enable','off', ...
   'Separator','on', ...
   'Tag','BVARConditionalPredictionEventAnnualDataPostDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Raw posterior draws                             %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarrawdraws = uimenu('Parent',controls.bvarmenu, ...
   'Label','&Raw Posterior Draws...', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','BVARRawPosteriorDrawsMenu');
%
% submenus for raw posterior draws
%
controls.bvarrawdrawspsi = uimenu('Parent',controls.bvarrawdraws, ...
   'Label','&Psi...', ...
   'Callback','BVARMenuFunctions BVARPsiRawDraws', ...
   'Enable','off', ...
   'Tag','BVARPsiRawPosteriorDrawsMenu');
%
controls.bvarrawdrawspi = uimenu('Parent',controls.bvarrawdraws, ...
   'Label','P&i...', ...
   'Callback','BVARMenuFunctions BVARPiRawDraws', ...
   'Enable','off', ...
   'Tag','BVARPiRawPosteriorDrawsMenu');
% 
controls.bvarrawdrawsomega = uimenu('Parent',controls.bvarrawdraws, ...
   'Label','&Omega...', ...
   'Callback','BVARMenuFunctions BVAROmegaRawDraws', ...
   'Enable','off', ...
   'Tag','BVAROmegaRawPosteriorDrawsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                       Sequential marginal likelihood                        %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarmarglike = uimenu('Parent',controls.bvarmenu, ...
   'Label','Sequential Marginal &Likelihood...', ...
   'Callback','BVARMenuFunctions MargLikelihoodChib', ...
   'Enable','on', ...
   'Tag','BVARMarginalLikelihhodMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                              Convergence tools                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarconvergence = uimenu('Parent',controls.bvarmenu, ...
   'Label','Con&vergence', ...
   'Enable','on', ...
   'Tag','BVARConvergenceMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                    Posterior mean estimates for the BVAR                    %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarpostmean = uimenu('Parent',controls.bvarconvergence, ...
   'Label','&Posterior Mean', ...
   'Enable','on', ...
   'Tag','BVARPPosteriorMeanConvergenceMenu');
%
controls.bvarpsimeanconvergence = uimenu('Parent',controls.bvarpostmean, ...
   'Label','&Psi...', ...
   'Callback','BVARMenuFunctions BVARMeanMedianConvergence', ...
   'Enable','off', ...
   'Tag','BVARPsiPosteriorMeanConvergenceMenu');
%
controls.bvarpimeanconvergence = uimenu('Parent',controls.bvarpostmean, ...
   'Label','P&i...', ...
   'Callback','BVARMenuFunctions BVARMeanMedianConvergence', ...
   'Enable','off', ...
   'Tag','BVARPiPosteriorMeanConvergenceMenu');
%
controls.bvaromegameanconvergence = uimenu('Parent',controls.bvarpostmean, ...
   'Label','&Omega...', ...
   'Callback','BVARMenuFunctions BVARMeanMedianConvergence', ...
   'Enable','off', ...
   'Tag','BVAROmegaPosteriorMeanConvergenceMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                   Posterior median estimates for the BVAR                   %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarpostmedian = uimenu('Parent',controls.bvarconvergence, ...
   'Label','Posterior &Median', ...
   'Enable','on', ...
   'Tag','BVARPPosteriorMedianConvergenceMenu');
%
controls.bvarpsimedianconvergence = uimenu('Parent',controls.bvarpostmedian, ...
   'Label','&Psi...', ...
   'Callback','BVARMenuFunctions BVARMeanMedianConvergence', ...
   'Enable','off', ...
   'Tag','BVARPsiPosteriorMedianConvergenceMenu');
%
controls.bvarpimedianconvergence = uimenu('Parent',controls.bvarpostmedian, ...
   'Label','P&i...', ...
   'Callback','BVARMenuFunctions BVARMeanMedianConvergence', ...
   'Enable','off', ...
   'Tag','BVARPiPosteriorMedianConvergenceMenu');
%
controls.bvaromegamedianconvergence = uimenu('Parent',controls.bvarpostmedian, ...
   'Label','&Omega...', ...
   'Callback','BVARMenuFunctions BVARMeanMedianConvergence', ...
   'Enable','off', ...
   'Tag','BVAROmegaPosteriorMedianConvergenceMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                              %
%                              Modesty statistics                              %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarmodesty.parent = uimenu('Parent',controls.bvarmenu, ...
   'Label','Modest&y Statistics', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','BVARModestyStatisticsMenu');

%
controls.bvarmodesty.postmode = uimenu('Parent',controls.bvarmodesty.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','BVARMenuFunctions BVARModestyStatistics', ...
   'Enable','off', ...
   'Tag','BVARModestyStatisticsPostModeMenu');
%
controls.bvarmodesty.posterior = uimenu('Parent',controls.bvarmodesty.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','BVARMenuFunctions BVARModestyStatistics', ...
   'Enable','off', ...
   'Tag','BVARModestyStatisticsPostDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                              %
%                               Prior densities                                %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarpriordensity = uimenu('Parent',controls.bvarmenu, ...
   'Label','Pr&ior Densities', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','BVARPriorDensitiesMenu');
%
controls.bvarpriordensitypsi = uimenu('Parent',controls.bvarpriordensity, ...
   'Label','&Psi...', ...
   'Callback','BVARMenuFunctions BVARPsiPriorDensity', ...
   'Enable','off', ...
   'Tag','BVARPsiPriorDensitiesMenu');
%
controls.bvarpriordensitypi = uimenu('Parent',controls.bvarpriordensity, ...
   'Label','P&i...', ...
   'Callback','BVARMenuFunctions BVARPiPriorDensity', ...
   'Enable','off', ...
   'Tag','BVARPiPriorDensitiesMenu');
%
controls.bvarpriordensityomega = uimenu('Parent',controls.bvarpriordensity, ...
   'Label','&Omega...', ...
   'Callback','BVARMenuFunctions BVAROmegaPriorDensity', ...
   'Enable','off', ...
   'Tag','BVAROmegaPriorDensitiesMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                              %
%                             Posterior densities                              %
%                                                                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.bvarpostdensity = uimenu('Parent',controls.bvarmenu, ...
   'Label','Posterior &Densities', ...
   'Enable','on', ...
   'Tag','BVARPosteriorDensitiesMenu');
%
controls.bvarpostdensitypsi = uimenu('Parent',controls.bvarpostdensity, ...
   'Label','&Psi...', ...
   'Callback','BVARMenuFunctions BVARPsiPosteriorDensity', ...
   'Enable','off', ...
   'Tag','BVARPsiPosteriorDensitiesMenu');
%
controls.bvarpostdensitypi = uimenu('Parent',controls.bvarpostdensity, ...
   'Label','P&i...', ...
   'Callback','BVARMenuFunctions BVARPiPosteriorDensity', ...
   'Enable','off', ...
   'Tag','BVARPiPosteriorDensitiesMenu');
%
controls.bvarpostdensityomega = uimenu('Parent',controls.bvarpostdensity, ...
   'Label','&Omega...', ...
   'Callback','BVARMenuFunctions BVAROmegaPosteriorDensity', ...
   'Enable','off', ...
   'Tag','BVAROmegaPosteriorDensitiesMenu');

%
% end of BVARMenuControls.m
%
