function HelpMenuFunctions(selector)
% HelpMenuFunctions: switch function for running the function on the help menu.
%
% USAGE:
%
%       HelpMenuFunctions(selector)
%
% REQUIRED INPUT: selector (string) that determines which sub-function should be applied.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: February 12, 2010.
%                        This version: March 17, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-02-2010: Updated the documentation.
%
% * 09-03-2010: Just in case, the function now runs "YADAEnableControls".
%
% * 01-01-2011: Updated the documentation.
%
% * 09-01-2011: Added support for unix and mac paths.
%
% * 12-01-2011: The function now supports unix and mac paths.
%
% * 27-01-2011: Use "web" to open html-files on unix and mac, and "open" to open pdf's.
%
% * 28-01-2011: The code now uses the open command as default for opening pdf documents. On windows
%               the dos call is used only when the open command fails.
%
% * 29-01-2011: The open command is only used for pdf's for matlab version 7 and later on windows.
%               Added the "YADAHomepage" case.
%
% * 01-06-2011: Updated the "About" dialog text.
%
% * 02-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 12-08-2013: Fixed an issue with copyright dating.
%
% * 28-01-2014: Updated the documentation.
%
% * 29-01-2014: Removed the calls to "shellcmd.exe".
%
% * 05-01-2015: Updated the documentation.
%
% * 20-01-2016: Updated the documentation.
%
% * 09-03-2017: Updated the documentation.
%
% * 17-03-2017: Added the case to open the html version of the help file in windoze.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% collect some inportant data structures
%
maingui = findobj('Type','figure','Tag','YADA');
controls = get(maingui,'UserData');
CurrINI = get(controls.filemenu,'UserData');
DSGEModel = get(controls.open,'UserData');
lasterr = '';
%
switch selector
   case 'HelpFile'
      drawnow;
      %
      if ispc==1;
         try;
            prog = 'hh.exe help\yada.chm &';
            stat = dos(prog);
         catch;
            if MatlabNumber>=7;
               web([pwd '\help\html\index.html'],'-browser');
            else;
               web([pwd '\help\html\index.html']);
            end;
         end;
      else;
         web([pwd '/help/html/index.html'],'-browser');
      end;
   case 'HTMLHelpFile'
      if MatlabNumber>=7;
         web([pwd '\help\html\index.html'],'-browser');
      else;
         web([pwd '\help\html\index.html']);
      end;
   case 'YADAManual'
      drawnow;
      %
      if ispc==1;
         if MatlabNumber>=7;
            try;
               winopen([pwd '\doc\yada.pdf']);
            catch;
               cmd = ['"' pwd '\doc\yada.pdf" &'];
               stat = dos(cmd);
            end;
         else;
            cmd = ['"' pwd '\doc\yada.pdf" &'];
            stat = dos(cmd);
         end;
      else;
         open([pwd '/doc/yada.pdf']);
      end;
   case 'ExtendYADA'
      drawnow;
      %
      if ispc==1;
         if MatlabNumber>=7;
            try;
               winopen([pwd '\doc\ExtendingYADA.pdf']);
            catch;
               cmd = ['"' pwd '\doc\ExtendingYADA.pdf" &'];
               stat = dos(cmd);
            end;
         else;
            cmd = ['"' pwd '\doc\ExtendingYADA.pdf" &'];
            stat = dos(cmd);
         end;
      else;
         open([pwd '/doc/ExtendingYADA.pdf']);
      end;
   case 'YADAHomepage'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         if MatlabNumber>=7;
            web('http://www.texlips.net/yada/','-browser');
         else;
            web('http://www.texlips.net/yada/');
         end;
         %
         set(controls.about,'UserData',0);
      end;
   case 'License'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         TextGUI(FixFilePath([pwd '\gpl.txt']),'GNU General Public License',[(CurrINI.scrsz(3)-700)/2 (CurrINI.scrsz(4)-400)/2 700 500],'License',40,CurrINI,1);
         set(controls.about,'UserData',0);
      end;
   case 'About'
      if get(controls.about,'UserData')==0;
         set(controls.about,'UserData',1);
         drawnow;
         %
         [VersionOfYADA,VersionDateStr] = YADAVersion;
         txt = strvcat(['YADA - Version ' num2str(VersionOfYADA,'%0.2f') ': ' VersionDateStr],'Anders Warne - New Area-Wide Model Project','DG-Research/Monetary Policy Research Division, European Central Bank (ECB)',' ','APPROPRIATE LEGAL NOTICES','This program is free software: you can redistribute it and/or modify it in accordance with the terms of the GNU General Public License (http://www.gnu.org/licenses/) as published by the Free Software Foundation, either Version 3 of the license, or (at your option) any later version.',' ','DISCLAIMER OF WARRANTY','By accepting the disclaimer you assume the entire risk related to your use of this program. The European Central Bank (ECB) provides this program ''as is'' and the ECB disclaims any warranties, whether express or implied, including, but not limited to, the implied warranties of merchantability and fitness for a particular purpose. The entire risk as to the quality and performance of the program is with you.',' ','LIMITATION OF LIABILITY','In no event shall the ECB be liable to you or to any third party for any direct, indirect, incidental, consequential, general, special or exemplary damages or lost profit resulting from any use of or inability to use the program (including but not limited to loss of data or data being rendered inaccurate or losses sustained by you or third parties or a failure of the program to operate with any other programs). Should the program prove defective, you assume the cost of all necessary servicing, repair and/or corrections.',' ','COPYRIGHT NOTICE',['This program is released under the GNU General Public License, Version 3, 29 June 2007 (http://www.gnu.org/licenses/) and it was last modified by the ECB on ' VersionDateStr '.'],' ','Copyright  2006-2017 European Central Bank.','Email: anders.warne@ecb.europa.eu');
         About(txt,'logo','About',500,600,CurrINI);
         drawnow;
         pause(0.02);
         set(controls.about,'UserData',0);
      end;
end;
set(controls.open,'UserData',DSGEModel);
set(controls.filemenu,'UserData',CurrINI);
%
% make sure that controls are enabled and disabled as they should
%
YADAEnableControls(DSGEModel,controls);

%
% end of HelpMenuFunctions.m
%
