function z = ChiSquareRndFcn(n,NumDraws)
% ChiSquareRndFcn: draws a vector of random data from a chi-square distribution
%
% USAGE:
%
%       z = ChiSquareRndFcn(n,NumDraws)
%
% REQUIRED INPUT:  n (integer) with the number of degrees of freedom of the
%                     chi-square distribution.
%
% OPTIONAL INPUT:  NumDraws (integer) with the length of the z vector.
%
% REQUIRED OUTPUT: z (vector) of dimension NumDraws.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: February 6, 2007.
%                        This version: March 22, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-11-2007: Updated the documentation.
%
% * 23-05-2008: Updated the documentation.
%
% * 22-01-2009: Updated the documentation.
%
% * 12-03-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 05-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 22-02-2016: Updated the documentation.
%
% * 22-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if nargin==1;
   NumDraws = 1;
end;
NumDraws = floor(NumDraws);
if NumDraws<1;
   NumDraws = 1;
end;
%
% use the fact that the chi-square distribution with n degrees of freedom is identical to the Gamma(n/2,2)
% distribution.
%
z = GammaRndFcn(n/2,2,NumDraws)';

%
% end of ChiSquareRndFcn.m
%
